@@ -27,13 +27,9 @@ import hashlib
 import M2Crypto
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.datavars import DataVars
-# from sudsds.client import Client
+import calculate.contrib
 from suds.client import Client
 from cert_verify import verify, get_CRL
-# from sudsds.transport.http import (HttpTransport, SUDSHTTPRedirectHandler,
-#                                    CheckingHTTPSConnection,
-#                                    CheckingHTTPSHandler,
-#                                    PYOPENSSL_AVAILABLE, PyOpenSSLSocket)
 import httplib
 from suds.transport.http import HttpTransport
 try:
@@ -42,8 +38,6 @@ except ImportError:
     PYOPENSSL_AVAILABLE = False
 else:
     PYOPENSSL_AVAILABLE = True
-# from sudsds.transport import Transport
-# from sudsds.properties import Unskin
 from suds.transport import Transport
 from suds.properties import Unskin
 
